nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

HwRuc0

Struct HwRuc0 

#[repr(transparent)]
pub struct HwRuc0(pub u32);
Hardware Restrict User Context 0

Tuple Fields

0: u32

Implementations

Source

impl HwRuc0

pub const fn lc_state(&self) -> LcState

Life cycle state based restrictions

pub const fn set_lc_state(&mut self, val: LcState)

Life cycle state based restrictions

pub const fn boot_state(&self) -> u16

Temporal boot state

pub const fn set_boot_state(&mut self, val: u16)

Temporal boot state

pub const fn cpu0_debug(&self) -> bool

Disable key access when debugger is attached to CPU0 after power-up

pub const fn set_cpu0_debug(&mut self, val: bool)

Disable key access when debugger is attached to CPU0 after power-up

pub const fn coolflux_debug(&self) -> bool

Disable key access when debugger is attached to COOLFLUX after power-up

pub const fn set_coolflux_debug(&mut self, val: bool)

Disable key access when debugger is attached to COOLFLUX after power-up

pub const fn dsp_debug(&self) -> bool

DSP debug status.

pub const fn set_dsp_debug(&mut self, val: bool)

DSP debug status.

pub const fn access_level(&self) -> u8

Restrict the key access based on TrustZone security level

pub const fn set_access_level(&mut self, val: u8)

Restrict the key access based on TrustZone security level