#[repr(transparent)]pub struct Sr(pub u32);Expand description
Status
Tuple Fields
0: u32Implementations
Sourceimpl Sr
impl Sr
Sourcepub const fn set_zeroized(&mut self, val: bool)
pub const fn set_zeroized(&mut self, val: bool)
Zeroized or Locked state
Sourcepub const fn set_rejected(&mut self, val: bool)
pub const fn set_rejected(&mut self, val: bool)
Operation rejected
Sourcepub const fn di_request(&self) -> bool
pub const fn di_request(&self) -> bool
Indicates the request for data in transfer via the DIR register
Sourcepub const fn set_di_request(&mut self, val: bool)
pub const fn set_di_request(&mut self, val: bool)
Indicates the request for data in transfer via the DIR register
Sourcepub const fn do_request(&self) -> bool
pub const fn do_request(&self) -> bool
Indicates the request for data out transfer via the DOR register
Sourcepub const fn set_do_request(&mut self, val: bool)
pub const fn set_do_request(&mut self, val: bool)
Indicates the request for data out transfer via the DOR register